PyXMake Developer Guide: PyXMake.VTL.sphinx Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Functions | Variables
PyXMake.VTL.sphinx Namespace Reference

## Functions
def | main (BuildID, masterfile, source=os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab","source"), output=os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab"), include=[os.path.join(__pyc_core_path,"Plugin","Smetana"), os, path, join, __pyc_core_path, Plugin, Smetana, src, Smetana, os, path, join, __pyc_core_path, Core, bin, __platform, __arch, scratch=VTL.Scratch, verbosity=2, kwargs)

## Variables
| parser = argparse.ArgumentParser(description="Build shared Fortran libraries for Python remotely on the institute cluster.")
| metavar
| nargs
| help
| args
| user = args.user[0]
| key = args.key[0]
| logo

## Detailed Description

    Triple-use minimum working example for PyXMake. This script can be
    executed in three different ways in varying levels of accessibility

    @note: Create documentations for PyXMake, PyCODAC and STMLab with Sphinx.
    Created on 05.08.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - PyXMake, PyCODAC

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ main()

def PyXMake.VTL.sphinx.main | ( |  | BuildID,
|  |  | masterfile,
|  |  | source = `os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab","source")`,
|  |  | output = `os.path.join(__pyc_core_path,"VTL","doc","mcd_stmlab")`,
|  |  | include = `[os.path.join(__pyc_core_path,"Plugin","Smetana")`,
|  |  | os,
|  |  | path,
|  |  | join,
|  |  | __pyc_core_path,
|  |  | Plugin,
|  |  | Smetana,
|  |  | src,
|  |  | Smetana,
|  |  | os,
|  |  | path,
|  |  | join,
|  |  | __pyc_core_path,
|  |  | Core,
|  |  | bin,
|  |  | __platform,
|  |  | __arch,
|  |  | scratch = `VTL.Scratch`,
|  |  | verbosity = `2`,
|  |  | kwargs
| ) |  |

    Main function to execute the script.

Definition at line 63 of file sphinx.py.